@@ -26,7 +26,7 @@ namespace xp
         #define xoffsetof(O, M)                                    \
         _Pragma("clang diagnostic push")                           \
         _Pragma("clang diagnostic ignored \"-Winvalid-offsetof\"") \
-        offsetof(O, M)                                             \
+        __builtin_offsetof(O, M)                                   \
         _Pragma("clang diagnostic pop")
     #else
         #ifdef __GNUC__
@@ -35,6 +35,11 @@ namespace xp
         #define xoffsetof(O, M) offsetof(O, M)
     #endif
 
+    #ifdef _MSC_VER
+        #undef min
+        #undef max
+    #endif
+
     /*************************
      * xproperty declaration *
      *************************/
@@ -67,8 +72,17 @@ namespace xp
         reference operator()() noexcept;
         const_reference operator()() const noexcept;
 
-        template <class Arg, class... Args>
-        xp_owner_type operator()(Arg&& arg, Args&&... args) && noexcept;
+        xp_owner_type operator()(value_type& arg) && noexcept;
+        xp_owner_type operator()(const value_type& arg) && noexcept;
+        xp_owner_type operator()(value_type&& arg) && noexcept;
+
+        template <class Arg1, class Arg2, class... Args>
+        xp_owner_type operator()(Arg1&& arg1, Arg2&& arg2, Args&&... args) && noexcept;
+
+
+        reference operator=(value_type& value);
+        reference operator=(const value_type& value);
+        reference operator=(value_type&& value);
 
         template <class V>
         reference operator=(V&& value);
@@ -254,14 +268,63 @@ namespace xp
         return m_value;
     }
 
+
     template <class T, class O, class D>
-    template <class Arg, class... Args>
-    inline auto xproperty<T, O, D>::operator()(Arg&& arg, Args&&... args) && noexcept -> xp_owner_type
+    inline auto xproperty<T, O, D>::operator()(value_type& arg) && noexcept -> xp_owner_type
     {
-        m_value = value_type(std::forward<Arg>(arg), std::forward<Args>(args)...);
+        m_value = arg;
         return std::move(*owner());
     }
 
+    template <class T, class O, class D>
+    inline auto xproperty<T, O, D>::operator()(const value_type& arg) && noexcept -> xp_owner_type
+    {
+        m_value = arg;
+        return std::move(*owner());
+    }
+
+    template <class T, class O, class D>
+    inline auto xproperty<T, O, D>::operator()(value_type&& arg) && noexcept -> xp_owner_type
+    {
+        m_value = std::move(arg);
+        return std::move(*owner());
+    }
+
+    template <class T, class O, class D>
+    template <class Arg1, class Arg2, class... Args>
+    inline auto xproperty<T, O, D>::operator()(Arg1&& arg1, Arg2&& arg2, Args&&... args) && noexcept -> xp_owner_type
+    {
+        m_value = value_type(std::forward<Arg1>(arg1), std::forward<Arg2>(arg2), std::forward<Args>(args)...);
+        return std::move(*owner());
+    }
+
+    template <class T, class O, class D>
+    inline auto xproperty<T, O, D>::operator=(value_type& value) -> reference
+    {
+        m_value = owner()->template invoke_validators<xp_derived_type>(value);
+        owner()->notify(derived_cast());
+        owner()->template invoke_observers<xp_derived_type>();
+        return m_value;
+    }
+
+    template <class T, class O, class D>
+    inline auto xproperty<T, O, D>::operator=(const value_type& value) -> reference
+    {
+        m_value = owner()->template invoke_validators<xp_derived_type>(value);
+        owner()->notify(derived_cast());
+        owner()->template invoke_observers<xp_derived_type>();
+        return m_value;
+    }
+
+    template <class T, class O, class D>
+    inline auto xproperty<T, O, D>::operator=(value_type&& value) -> reference
+    {
+        m_value = owner()->template invoke_validators<xp_derived_type>(std::move(value));
+        owner()->notify(derived_cast());
+        owner()->template invoke_observers<xp_derived_type>();
+        return m_value;
+    }
+
     template <class T, class O, class D>
     template <class V>
     inline auto xproperty<T, O, D>::operator=(V&& value) -> reference
